# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define cvs_version 1_7R2

Name:           rhino
Version:        1.7
Release:        0.7.r2.3%{?dist}
Epoch:          0
Summary:        JavaScript for Java
License:        GPL+ and LGPLv2+ and Netscape and MPLv1.0 and (MPLv1.1 or GPLv2+)

Source0:        ftp://ftp.mozilla.org/pub/mozilla.org/js/rhino%{cvs_version}.zip

Source2:        %{name}.script
Source3:        %{name}-%{version}-openjdk-build.xml

Patch0:         %{name}-build.patch
# Patch to try several methods of loading jline library or fail gracefully
Patch1:         %{name}-457336.diff
URL:            http://www.mozilla.org/rhino/
Group:          Development/Libraries/Java

BuildRequires:  ant
BuildRequires:  java-1.6.0-openjdk-devel
BuildRequires:  jpackage-utils
Requires:       jpackage-utils
Requires:       jline

# Disable xmlbeans until we can get it into Fedora
#Requires:       xmlbeans
#BuildRequires:  xmlbeans
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n) 

Obsoletes:      %{name}-manual <= %{epoch}:%{version}-%{release}

%description
Rhino is an open-source implementation of JavaScript written entirely
in Java. It is typically embedded into Java applications to provide
scripting to end users.

#%package        demo
#Summary:        Examples for %{name}
#Group:          Development/Libraries/Java

#%description    demo
#Examples for %{name}.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

Requires:       jpackage-utils
BuildRequires:  jpackage-utils

%description    javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{name}%{cvs_version}
%patch0 -p1
%patch1 -p0 -b .jline

find -name "*.jar" -exec rm -f '{}' \;

# Fix build
%{__perl} -pi -e 's|.*<get.*src=.*>\n||' build.xml testsrc/build.xml toolsrc/org/mozilla/javascript/tools/debugger/build.xml xmlimplsrc/build.xml

# Fix manifest
%{__perl} -pi -e 's|^Class-Path:.*\n||g' src/manifest

# Add jpp release info to version
%{__perl} -pi -e 's|^implementation.version: Rhino .* release .* \${implementation.date}|implementation.version: Rhino %{version} release %{release} \${implementation.date}|' build.properties

%build
export CLASSPATH=
export OPT_JAR_LIST=:
%ant -Dxbean.jar=$(build-classpath xmlbeans/xbean) \
     -Djsr173.jar=$(build-classpath bea-stax-api) deepclean jar copy-all javadoc

# Magic for OpenJDK
cp -a src src-openjdk
cp -a toolsrc toolsrc-openjdk
cp -a xmlimplsrc xmlimplsrc-openjdk
cp -a deprecatedsrc deprecatedsrc-openjdk 
rm -rf deprecatedsrc-openjdk/org/mozilla/javascript/xml

for dir in *-openjdk; do
    pushd $dir
        mkdir sun
        mv org sun
    popd
done

cp %{SOURCE3} build-openjdk.xml
ant -f build-openjdk.xml 

pushd examples
# xbeans component is optional. Disabled until we can get it into Fedora
#export CLASSPATH=../build/%{name}%{cvs_version}/js.jar:$(build-classpath xmlbeans/xbean)

export CLASSPATH=../build/%{name}%{cvs_version}/js.jar:$(build-classpath xmlbeans/xbean 2>/dev/null)
%{javac} *.java
%{jar} cvf ../build/%{name}%{cvs_version}/%{name}-examples-%{version}.jar *.class
popd

%install
%__rm -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -a build/%{name}%{cvs_version}/js.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%{__cp} -a build/%{name}%{cvs_version}/%{name}-examples-%{version}.jar %{buildroot}%{_javadir}/%{name}-examples-%{version}.jar
(cd %{buildroot}%{_javadir} && %{__ln_s} %{name}-%{version}.jar js-%{version}.jar)
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do %{__ln_s} ${jar} `echo $jar| %{__sed} "s|-%{version}||g"`; done)

# javadoc
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__cp} -a build/%{name}%{cvs_version}/javadoc/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}
%{_bindir}/find %{buildroot}%{_javadocdir}/%{name}-%{version} -type f -name '*.html' | %{_bindir}/xargs %{__perl} -pi -e 's/\r$//g'

## script
%__mkdir_p %{buildroot}%{_bindir}
%__install -m 755 %{SOURCE2} %{buildroot}%{_bindir}/%{name}

# examples
#%{__mkdir_p} %{buildroot}%{_datadir}/%{name}
#%{__cp} -a examples/* %{buildroot}%{_datadir}/%{name}

%clean
%__rm -rf %{buildroot}

%files
%defattr(0644,root,root,0755)
%doc LICENSE.txt
%attr(0755,root,root) %{_bindir}/*
%{_javadir}/*

#%files demo
#%defattr(0644,root,root,0755)
#%{_datadir}/%{name}

%files javadoc
%doc LICENSE.txt
%defattr(0644,root,root,0755)
%doc %{_javadocdir}/*

%changelog
* Fri Mar 18 2011 Deepak Bhole <dbhole@redhat.com> 1.7-0.7.r2.3
- Added License
- Remove pre-built jars
- Added BR on jpackage-utils

* Tue Oct 05 2010 Deepak Bhole <dbhole@redhat.com> - 0:1.7-0.7.r2.2.el5
- Import from el6
- Resolves: bz618837

